@@ -45,7 +45,8 @@
 
 extern gchar *global_settings_dir;
 extern gchar *global_backup_name;
-extern int repopulate_on_combo_change;
+
+gulong backup_combo_changed_signal;
 
 
 
@@ -124,7 +125,7 @@ void del_treeview_row(struct w *widgets)
 }
 
 
-/* New backup name selected, show this backup in the combo if its not already selected */
+/* New backup name selected */
 void backup_name_combo_changed(struct w *widgets)
 {
     int i = 0;
@@ -139,10 +140,9 @@ void backup_name_combo_changed(struct w *widgets)
     /* Set schedule spinbuttons to default time */
     for(i=0; i<2; i++)
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[i]), 1);
-    
-    /* Dont repopulate when text is set to "active" in populate_rsync_tab() */
-    if( repopulate_on_combo_change )
-      populate_rsync_tab(widgets);
+
+
+    populate_rsync_tab(widgets);
 }
 
 
@@ -455,8 +455,6 @@ void create_rsync_tab(struct w *widgets)
     g_signal_connect(delete_dest_cell_renderer, "toggled",  
 		      G_CALLBACK(treeview_toggle_button_clicked), widgets);
 
-
-// New.
     user_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(user_cell_renderer, "editable", TRUE, NULL);
     g_signal_connect(user_cell_renderer, "edited",  
@@ -471,7 +469,6 @@ void create_rsync_tab(struct w *widgets)
     g_object_set(priv_key_path_cell_renderer, "editable", TRUE, NULL);
     g_signal_connect(priv_key_path_cell_renderer, "edited",  
 		      G_CALLBACK(cell_edited), widgets);
-// New end.
 
 
     colnr  = 0;
@@ -508,8 +505,6 @@ void create_rsync_tab(struct w *widgets)
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->backup_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
     colnr++;
 
-
-// New
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Remote username"), user_cell_renderer, "text", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->backup_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
     colnr++;
@@ -521,14 +516,8 @@ void create_rsync_tab(struct w *widgets)
     col[colnr] = gtk_tree_view_column_new_with_attributes(_("Private key for remote server"), priv_key_path_cell_renderer, "text", colnr, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->backup_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
     colnr++;
-// End new.
 
 
-    /* Ugly: Show treeview example usage in a tooltip */
-//    gtk_tooltips_set_tip(tooltips, widgets->backup_treeview,
-//    _("This backup list can be edited by clicking in the cells.\nHere are some examples:\nSource or destination server: User@Server:Port\nSource/destination directory or file: /home/user2/Photos\nInclude/exclude patterns can be used like this: *.ogg, *.txt"),
-//    NULL);
-
     g_object_set_data(G_OBJECT(src_host_cell_renderer), "column", (void*)(0));
     g_object_set_data(G_OBJECT(src_cell_renderer), "column", (void*)(1));
     g_object_set_data(G_OBJECT(dst_host_cell_renderer), "column", (void*)(2));
@@ -539,11 +528,9 @@ void create_rsync_tab(struct w *widgets)
     g_object_set_data(G_OBJECT(incl_backup_cell_renderer), "column", (void*)(6));
     g_object_set_data(G_OBJECT(delete_dest_cell_renderer), "column", (void*)(7));
 
-// New.
     g_object_set_data(G_OBJECT(user_cell_renderer), "column", (void*)(8));
     g_object_set_data(G_OBJECT(port_cell_renderer), "column", (void*)(9));
     g_object_set_data(G_OBJECT(priv_key_path_cell_renderer), "column", (void*)(10));
-// End new.
 
 
     /* Add a settings frame in a table */
@@ -580,8 +567,13 @@ void create_rsync_tab(struct w *widgets)
     /* Selected backup combo */
     utf8 = g_locale_to_utf8(_(" Selected backup: "), -1, NULL, NULL, NULL);
     widgets->rsync_set_combo[0] = make_label_combo_button(GTK_TABLE(widgets->usr_set_table), del_backup_button, utf8, 0,1,a,b, 350);
-    g_signal_connect_swapped(widgets->rsync_set_combo[0], "changed",
-                    	     G_CALLBACK(backup_name_combo_changed), widgets);
+
+    /* Callback for combo changed. Save the signal id so the signal emission can be blocked. */
+    backup_combo_changed_signal = g_signal_connect_swapped(widgets->rsync_set_combo[0], "changed",
+                    	        		    G_CALLBACK(backup_name_combo_changed), widgets);
+
+
+
     a++; b++;
 
 
